Documentation
¶
Index ¶
Constants ¶
const ( VersionName = "fuxi" // Major version name in the Roadmap: Pangu 0.8; Nuwa 1.0; Fuxi 2.0; Shennong 2.0+; VersionMajor = 2 // Major version component of the current release VersionMinor = 1 // Minor version component of the current release VersionPatch = 0 // Patch version component of the current release VersionMeta = "stable" // Version metadata to append to the version string, rc/stable )
Variables ¶
var Version = func() string { v := fmt.Sprintf("%d.%d.%d", VersionMajor, VersionMinor, VersionPatch) if VersionMeta != "" { v += "-" + VersionMeta } return v }()
Version holds the textual version string.
var VersionNum = func() string { v := fmt.Sprintf("%d.%d.%d", VersionMajor, VersionMinor, VersionPatch) return v }()
VersionNum only returns the version number.
var VersionWithName = func() string { v := fmt.Sprintf("%s %d.%d.%d", VersionName, VersionMajor, VersionMinor, VersionPatch) if VersionMeta != "" { v += "-" + VersionMeta } return v }()
Version holds the textual version string with Full name.
Functions ¶
func VersionWithCommit ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.